The branch, master has been updated
       via  3a3ac7caaba1a8a8d4a69900c943c1a3c7c70151 (commit)
      from  76a864be5caf24a319d5946ed4bfafe67981e54f (commit)


- Log -----------------------------------------------------------------
commit 3a3ac7caaba1a8a8d4a69900c943c1a3c7c70151
Author: Dieter Adriaenssens <[email protected]>
Date:   Mon Oct 4 20:49:05 2010 +0200

    bug #3077454, don't apply inner_sql span to query_only mode, this breaks 
copying databases and rowcount of queries

-----------------------------------------------------------------------

Summary of changes:
 libraries/sqlparser.lib.php |   12 ++++++++----
 1 files changed, 8 insertions(+), 4 deletions(-)

diff --git a/libraries/sqlparser.lib.php b/libraries/sqlparser.lib.php
index 793ae26..a9568c4 100644
--- a/libraries/sqlparser.lib.php
+++ b/libraries/sqlparser.lib.php
@@ -2119,10 +2119,12 @@ if (! defined('PMA_MINIMUM_COMMON')) {
                 $docu                               = TRUE;
                 break;
         } // end switch
         // inner_sql is a span that exists for all cases
         // of $cfg['SQP']['fmtType'] to make possible a replacement
         // for inline editing
-        $str .= '<span class="inner_sql">';
+        if ($mode!='query_only') {
+               $str .= '<span class="inner_sql">';
+       }
         $close_docu_link = false;
         $indent                                     = 0;
         $bracketlevel                               = 0;
@@ -2617,8 +2619,10 @@ if (! defined('PMA_MINIMUM_COMMON')) {
             $str .= '</a>';
             $close_docu_link = false;
         }
-        // close inner_sql span
-        $str .= '</span>';
+        if ($mode!='query_only') {
+               // close inner_sql span
+               $str .= '</span>';
+       }
         if ($mode=='color') {
             // close syntax span
             $str .= '</span>';
@@ -2119,10 +2119,12 @@ if (! defined('PMA_MINIMUM_COMMON')) {
                 break;
         } // end switch
-        // inner_sql is a span that exists for all cases
+        // inner_sql is a span that exists for all cases, except query_only
         // of $cfg['SQP']['fmtType'] to make possible a replacement
         // for inline editing


hooks/post-receive
-- 
phpMyAdmin

------------------------------------------------------------------------------
Virtualization is moving to the mainstream and overtaking non-virtualized
environment for deploying applications. Does it make network security 
easier or more difficult to achieve? Read this whitepaper to separate the 
two and get a better understanding.
http://p.sf.net/sfu/hp-phase2-d2d
_______________________________________________
Phpmyadmin-git mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/phpmyadmin-git

Reply via email to